about summary refs log tree commit diff
path: root/pkgs/servers/dns
diff options
context:
space:
mode:
authorTQ Hirsch <thequux@thequux.com>2023-06-29 12:42:01 +0200
committerNick Cao <nickcao@nichi.co>2023-07-01 18:55:51 +0800
commitdd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e (patch)
tree8eeb39d8e9f8a0a840558d8944ad0bd72bd73604 /pkgs/servers/dns
parent8ab22ad2ad166a75e517bc3d0a6625d3e3f4517a (diff)
downloadnixlib-dd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e.tar
nixlib-dd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e.tar.gz
nixlib-dd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e.tar.bz2
nixlib-dd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e.tar.lz
nixlib-dd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e.tar.xz
nixlib-dd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e.tar.zst
nixlib-dd481f2ee3bcf8e0555968dbdaa03a45bd5ae56e.zip
pdns: Changed paths in /etc to use pdns instead of powerdns
Diffstat (limited to 'pkgs/servers/dns')
-rw-r--r--pkgs/servers/dns/pdns-recursor/default.nix4
-rw-r--r--pkgs/servers/dns/pdns/default.nix6
2 files changed, 5 insertions, 5 deletions
diff --git a/pkgs/servers/dns/pdns-recursor/default.nix b/pkgs/servers/dns/pdns-recursor/default.nix
index c8da5d9de60c..da0890e8e4d0 100644
--- a/pkgs/servers/dns/pdns-recursor/default.nix
+++ b/pkgs/servers/dns/pdns-recursor/default.nix
@@ -21,10 +21,10 @@ stdenv.mkDerivation rec {
   configureFlags = [
     "--enable-reproducible"
     "--enable-systemd"
-    "sysconfdir=/etc/powerdns-recursor"
+    "sysconfdir=/etc/pdns-recursor"
   ];
 
-  installFlags = [ "sysconfdir=$(out)/etc/powerdns-recursor" ];
+  installFlags = [ "sysconfdir=$(out)/etc/pdns-recursor" ];
 
   enableParallelBuilding = true;
 
diff --git a/pkgs/servers/dns/pdns/default.nix b/pkgs/servers/dns/pdns/default.nix
index e998a1e5cf98..fcd218a1f3cc 100644
--- a/pkgs/servers/dns/pdns/default.nix
+++ b/pkgs/servers/dns/pdns/default.nix
@@ -69,7 +69,7 @@ stdenv.mkDerivation (finalAttrs: {
     "--with-libsodium"
     "--with-sqlite3"
     "--with-libcrypto=${openssl.dev}"
-    "sysconfdir=/etc/powerdns"
+    "sysconfdir=/etc/pdns"
   ];
 
   # nix destroy with-modules arguments, when using configureFlags
@@ -81,9 +81,9 @@ stdenv.mkDerivation (finalAttrs: {
   '';
 
   # We want the various utilities to look for the powerdns config in
   # /etc/powerdns, but to actually install the sample config file in
   # $out
-  installFlags = [ "sysconfdir=$(out)/etc/powerdns" ];
+  installFlags = [ "sysconfdir=$(out)/etc/pdns" ];
 
   enableParallelBuilding = true;
   doCheck = true;
@@ -81,9 +81,9 @@ stdenv.mkDerivation (finalAttrs: {
 
   # We want the various utilities to look for the powerdns config in
-  # /etc/powerdns, but to actually install the sample config file in
+  # /etc/pdns, but to actually install the sample config file in
   # $out